#
# spec file for package minetest-game
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           minetest-game
Version:        5.8.0
Release:        1.4
Summary:        Minetest Game
License:        CC-BY-3.0 AND CC-BY-SA-3.0 AND LGPL-2.1-or-later AND CC-BY-SA-4.0 AND CC0-1.0
Group:          Amusements/Games/3D/Simulation
URL:            https://minetest.net/
Source0:        https://github.com/minetest/minetest_game/archive/%{version}/minetest_game-%{version}.tar.gz
BuildRequires:  fdupes
Requires:       minetest-runtime >= %{version}
BuildArch:      noarch

%description
The main game for the Minetest game engine.

%prep
%setup -q -n minetest_game-%{version}

%build
# Nothing to build.

%install
mkdir -p %{buildroot}%{_datadir}/minetest/games/minetest_game
cp -ar * %{buildroot}%{_datadir}/minetest/games/minetest_game
%fdupes -s %{buildroot}%{_datadir}/minetest/games/minetest_game

%files
%license LICENSE.txt
%doc README.md
%dir %{_datadir}/minetest/
%dir %{_datadir}/minetest/games/
%{_datadir}/minetest/games/minetest_game/

%changelog
* Thu Jan  4 2024 Simon Vogl <simon.vogl@gmx.net>
- Update to version 5.8.0:
  * New water textures (the old ones were non-free) (Lopano)
  * Improve leaves textures in "Opaque Leaves" mode (Wuzzy)
  * When a player dies in protected air, bones now spawn as a
    block instead of dropping as an item (OgelGames)
  * Add API for sapling growth (aegroto)
  * Hook callbacks for default.set_inventory_action_loggers
    (appgurueu)
  * Fix logic error in bed rotation (fluxionary)
  * Fix coral and kelp duplication glitch with sticky piston from
    Mesecons mod (zmv7)
  * Fix players being able to skip many nights at once by
    spam-clicking bed (appgurueu)
  * Fix not updating vessel shelf infotext (Niklp)
  * Fix bookshelf infotext not updating when adding, removing or
    moving items inside (Montandalar, appgurueu)
  * Update translations: German (Wuzzy), Spanish (David Leal),
    Ukrainian (Andriy), French (xin)
* Fri Apr 14 2023 Simon Vogl <simon.vogl@gmx.net>
- Update to version 5.7.0:
  * Limit and sanitize formspec fields (appgurueu)
  * Fix player_api.set_model not updating the animation (appgurueu)
  * Ensure chests close properly (fluxionary)
  * Ensure proper creative hand override (AntumDeluge)
  * Fix error if /home is executed with an invalid name (zmv7)
  * Fix wall craft registrations (alek13)
  * Screwdriver: 4dir node support (Wuzzy)
* Wed Sep 28 2022 Simon Vogl <simon.vogl@gmx.net>
- Update to version 5.6.1:
  * Various bug fixes
* Thu Aug 18 2022 Ferdinand Thiessen <rpm@fthiessen.de>
- Update to version 5.6.0 to match up minetest version
  * Improved cart movement behavior
  * Dynamic shadow intensity increases with cloud density
  * Allow mods to override player animation globalstep
  * Log API added
  * New translation: Polish
  * Translation updates: Ukrainian, Russian, German, Lojban, and Esperanto
  * Various bug fixes
* Sat Jul 30 2022 Simon Vogl <simon.vogl@gmx.net>
- Update to version 5.5.0 & 5.5.1:
  * Add “Read” and “Write” tabs to book interface when you own the book (orbea)
  * Allow to write books without text or title (orbea)
  * Make identical keys stackable (Luis Royer)
  * Fix creative inventory trash slot not working for player named “trash” (Montandalar)
  * Fix sunlight propagation for glass stair/slab (An0n3m0us)
  * Fix glass bottle with firefly not being placable in vessels shelf (An0n3m0us)
  * Other bugfixes
  * Translations: Esperanto (Jason Cartwright), Russian (ptah-alexs), Japanese (nogajun), German (Wuzzy), Slovak (Daretmavi), French (Olivier Dragon), Swedish (ROllerozxa), Chinese (雷哲翰), Ukrainian (baytuch)
  * player_api mod: Fix crash if player has no model (appgurueu)
  * player_api mod: Mods can now override globalstep by overriding player_api.globalstep (LoneWolfHT)
  * Shadow intensity (of dynamic shadows) changes with weather (lhofhansl)
  * Some cart movement behavior fixes (SmallJoker)
  * Fix some translations in uk and ru locales (baytuch)
* Mon Apr 19 2021 Maximilian Trummer <opensuse@trummer.xyz>
- Update to version 5.4.1:
  * This is a maintenance release based on 5.4.0,
    it contains bugfixes but no new features.
* Wed Feb 24 2021 Ferdinand Thiessen <rpm@fthiessen.de>
- Dropped rpmlintrc
- Update to 5.4.0:
  * Add crafting guide
  * Added 5 wood variants of Mese Post Light
  * Add environment sounds for lava and active furnace
  * Change several block sounds
  * Fix players sleeping in an occupied bed
  * Fix 'sleepwalking' in bed
  * Fix sleeping player flying off the bed when damaged and flying
    far away from the bed after death
  * Fix sleeping player being immobilized and bed undiggable after
    death
  * Fix furnace infotext not always updating when removing item
  * New translation: Slovak, Brazilian Portuguese and
    Lojban (admittedly not a very good translation)
  * Update existing translations
* Tue Sep  8 2020 Maximilian Trummer <opensuse@trummer.xyz>
- Changed requirement for minetest-runtime to greater or equal,
  since running the game in a higher engine version works as well.
* Tue Sep  8 2020 Dirk Stoecker <opensuse@dstoecker.de>
- require minetest-runtime
* Wed Jul 29 2020 Martin Rey <mrey@suse.com>
- Update to version 5.3.0
  * Rename “Dry Dirt” and related blocks to “Savanna Dirt” and
    similar (paramat)
  * Added Wild Cotton: grows in savannas, drops Cotton Seeds
    (paramat)
  * Sort items into correct categories (An0n3m0us)
  * Tune cloud density variation (paramat)
  * Fix broken Creative inventory search in translation (sfan5)
  * Make Straw Stairs/Slabs usable as fuel (Paul Ouellette)
  * New textures: Dry Shrub, Brake Rail (Extex101, Hooded Ice)
  * Block particles when leaves decay, TNT explodes (sfan5)
- Use spec-cleaner on spec file
* Mon Apr  6 2020 Maximilian Trummer <opensuse@trummer.xyz>
- Update to version 5.2.0
  * Simple weather that varies the clouds (paramat)
  * More realistic boat physics (gang65)
  * Creative Inventory search:
    Item with exact match appears in first spot (sfan5)
  * Creative Inventory: More visual tweaks (Andrey2470T)
  * Improve player model animation (An0n3m0us)
  * Increase water opacity (lhofhansl)
  * Reset spawn position when bed is destroyed (Desour)
  * Papyrus now appears in rainforest swamps as well (paramat)
  * New/updated translations:
    + French (DrHackberrry)
    + Spanish (runsy)
    + Italian (h4ml3t)
    + Russian (Andrey2470T)
    + Swedish (Aresiel)
    + Malay (MuhdNurHidayat)
    + Chinese (zaoqi, IFRFSX)
  * Bugfix: TNT mod crashed when entities disappeared
    during explosion (sfan5)
  * Bugfix: Papyrus in savanna did not appear in 5.1.0,
    it has been added back (paramat)
  * Bugfix: Screwdriver was able to rotate torches
    into weird positions (An0n3m0us)
  * Bugfix: Players could be knocked back when attached (sfan5)
* Sat Jan 18 2020 Maximilian Trummer <opensuse@trummer.xyz>
- Update to version 5.1.1
  * See https://dev.minetest.net/Changelog#5.1.0_.E2.86.92_5.1.1
  * no changes, this is only a version bump to keep the
    package version in sync with minetest
* Sun Oct 13 2019 Maximilian Trummer <opensuse@trummer.xyz>
- Update to version 5.1.0
  * See https://dev.minetest.net/Changelog#5.0.0_.E2.86.92_5.0.1
  * Added dry dirt and dry dirt with dry grass. Grass never spreads on dry dirt
  * Savannas now have dry dirt and dry dirt with dry grass
  * Added steel bar door and steel bar trap door
  * Added setting “enable_fence_tall” for fences that cannot be jumped over (mbartlett21)
  * Firefly in a bottle can now be placed into vessels shelf
  * Add flowing water sound
  * Underground biomes extend much deeper, down to Y=-255
  * Make the creative mod hand dig 'dig_immediate' nodes fast (paramat)
  * Add new TNT sounds (TumeniNodes)
  * Add missing infotext to nodes (An0n3m0us)
  * Added translation support
  * Added German, French, Spanish and Italian translations (Wuzzy, Hamlet, JDiaz, DrHackberry)
* Tue Apr  2 2019 Maximilian Trummer <opensuse@trummer.xyz>
- Update to version 5.0.1
  * See https://dev.minetest.net/Changelog#5.0.0_.E2.86.92_5.0.1
* Sun Mar 24 2019 Maximilian Trummer <opensuse@trummer.xyz>
- Update to version 5.0.0
  * See https://dev.minetest.net/Changelog#0.4.16_.E2.86.92_5.0.0
* Tue Aug  7 2018 sor.alexei@meowr.ru
- Update to version 0.4.17:
  * Fix boo#1103904
  * See https://dev.minetest.net/Changelog#0.4.16_.E2.86.92_0.4.17
- Add the licence file to the package.
* Mon Jan 22 2018 opensuse@trummer.xyz
- Don't require minetest, to make headless installation possible
* Mon Jun  5 2017 sor.alexei@meowr.ru
- Update to version 0.4.16:
  * See http://dev.minetest.net/Changelog#0.4.15_.E2.86.92_0.4.16
* Tue Jan 10 2017 rpm@fthiessen.de
- Added minetest-game-rpmlintrc to fix build on openSUSE 13.1
* Mon Dec 26 2016 mailaender@opensuse.org
- Update to version 0.4.15
* Wed Jul 27 2016 jengelh@inai.de
- Update License field
* Mon May 16 2016 rpm@fthiessen.de
- Update to 0.4.14
* Wed Nov 25 2015 rpm@fthiessen.de
- Update to 0.4.13
* Thu Feb 19 2015 khyota@redhyena.net
- update 0.4.12
* Sun Sep 21 2014 mailaender@opensuse.org
- update 0.4.10
* Tue Jan  7 2014 mailaender@opensuse.org
- update 0.4.9
* Thu Aug  8 2013 opensuse@dstoecker.de
- update to 0.4.7
* Fri Apr 12 2013 mailaender@opensuse.org
- update to version 0.4.6
* Sun Dec  9 2012 m407@mail.ru
- Build version 0.4.4
* Sun Sep 23 2012 joop.boonen@opensuse.org
- Renamed the spec and changes file to the correct name
- Removed the creative mod as it's currently broken
- Used fdupes to get link duplicate file
* Sat Sep 22 2012 joop.boonen@opensuse.org
- Build version 0.4.3
* Fri Aug 10 2012 jengelh@inai.de
- Remove redundant tags/sections from specfile
- Always build for noarch
* Fri Aug 10 2012 m407@mail.ru
- Initial package (version 0.4.1) for build.opensuse.org
